ReferenceCore
Core
Lorem ipsum dolor sit amet, consectetur adipiscing elit. These helpers create a workflow filestructure.
Precompiled libraries
def make_paths(root: str = '.', create: bool = True) -> dict| Name | Type | Description |
|---|---|---|
root | str | Lorem ipsum dolor sit amet. Default is .. |
create | bool | Consectetur adipiscing elit. Default is True. |
Python
def make_sample_data(path_names: dict, n_files: int = 3) -> NoneC#
def map_files(folder: str, file_ext: str = 'csv') -> dictPackage install
Nullam quis risus eget urna mollis ornare vel eu leo. These helpers create a workflow filestructure.
Install from a package index
import ability as ab
paths = ab.make_paths()
ab.make_sample_data(paths, n_files=3)Install optional extras
import ability as ab
mapped = ab.map_files("raw", file_ext="csv")
print(mapped)Environment checks
Duis mollis, est non commodo luctus, nisi erat porttitor ligula, eget lacinia odio sem nec elit.
Probe the install
import ability as ab
for device in ab.supported_devices():
print(device.id, device.label)